@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.26'; 
+$VERSION = '0.27'; 
 
 use Carp qw(carp croak);
 use Errno qw(ETIMEDOUT ECONNRESET);
@@ -33,14 +33,14 @@ require HTTP::Response;
 
 # Global stuff for checks etc.
 my $validOpts = {
-        types => {
-                'continuation'  => 1,
-                'text'          => 1,
-                'binary'        => 1,
-                'ping'          => 1,
-                'pong'          => 1,
-                'close'         => 1,
-        }
+	types => {
+		'continuation'  => 1,
+		'text'          => 1,
+		'binary'        => 1,
+		'ping'          => 1,
+		'pong'          => 1,
+		'close'         => 1,
+	}
 };
 
 =head1 NAME
@@ -112,75 +112,75 @@ Create a new object, takes 1 argument.. a fully qualified websocket URI.
 =cut
 
 sub new {
-        my ($class,$uri) = @_;
+	my ($class,$uri) = @_;
 
-        my $self = bless {
-                alias   => __PACKAGE__,
-                session => 0,
-        }, $class;
+	my $self = bless {
+			alias   => __PACKAGE__,
+			session => 0,
+	}, $class;
 
-        my ($scheme, $auth, $path, $query, $frag) = uri_split($uri);
-        my ($host,$port) = split(/:/,$auth);
+	my ($scheme, $auth, $path, $query, $frag) = uri_split($uri);
+	my ($host,$port) = split(/:/,$auth);
 
-        # If we are on WSS we are probably using https, if not probably http
-        if (!$port) {
-                if (uc($scheme) eq 'WSS')       { $port = 443 }
-                else                            { $port = 80 }
-        }
+	# If we are on WSS we are probably using https, if not probably http
+	if (!$port) {
+			if (uc($scheme) eq 'WSS')       { $port = 443 }
+			else                            { $port = 80 }
+	}
 
-       
-        my $key = "";
-        for (1..16) { $key .= int(rand(9)) }
+   
+	my $key = "";
+	for (1..16) { $key .= int(rand(9)) }
 
-        $self->{session} = POE::Session->create(
-                package_states => [
-                        $self => {
-                                _start          =>      '_start',
-                                _stop           =>      '_stop',
-                                keep_alive      =>      '_keep_alive',
-                                connect         =>      '_connect',
-                                handler         =>      '_handler',
-                                origin          =>      '_origin',
-                                send            =>      '_send',
-                                parent          =>      '_parent',
-                                socket_birth    =>      '_socket_birth',
-                                socket_death    =>      '_socket_death',
-                                socket_input    =>      '_socket_input',
-                        }
-                ],
-                heap => {
-                        parent          => POE::Kernel->get_active_session()->ID,
-                        handlers        => {
-                                read            =>      'websocket_read',
-                                connected       =>      'websocket_connected',
-                                handshake       =>      'websocket_handshake',
-                                disconnected    =>      'websocket_disconnected',
-                                error           =>      'websocket_error',
-                        },
-                        uri             => {
-                                scheme          => $scheme,
-                                auth            => $auth,
-                                path            => $path,
-                                query           => $query,
-                                frag            => $frag,
-                                host            => $host,
-                                port            => $port,
-                        },
-                        req             => {
-                                'origin'                =>      'http://'.$host,
-                                'sec-websocket-key'     =>      encode_base64($key),
-                        },
-                        _state          => {
-                                run             =>      1,
-                                frame           =>      Protocol::WebSocket::Frame->new,
-                        },
-                
-                }
-        );
-    
-        $self->{id} = $self->{session}->ID;
+	$self->{session} = POE::Session->create(
+			package_states => [
+				$self => {
+					_start          =>      '_start',
+					_stop           =>      '_stop',
+					keep_alive      =>      '_keep_alive',
+					connect         =>      '_connect',
+					handler         =>      '_handler',
+					origin          =>      '_origin',
+					send            =>      '_send',
+					parent          =>      '_parent',
+					socket_birth    =>      '_socket_birth',
+					socket_death    =>      '_socket_death',
+					socket_input    =>      '_socket_input',
+				}
+			],
+			heap => {
+				parent          => POE::Kernel->get_active_session()->ID,
+				handlers        => {
+					read            =>      'websocket_read',
+					connected       =>      'websocket_connected',
+					handshake       =>      'websocket_handshake',
+					disconnected    =>      'websocket_disconnected',
+					error           =>      'websocket_error',
+				},
+				uri             => {
+					scheme          => $scheme,
+					auth            => $auth,
+					path            => $path,
+					query           => $query,
+					frag            => $frag,
+					host            => $host,
+					port            => $port,
+				},
+				req             => {
+					'origin'                =>      'http://'.$host,
+					'sec-websocket-key'     =>      encode_base64($key),
+				},
+				_state          => {
+					run             =>      1,
+					frame           =>      Protocol::WebSocket::Frame->new,
+				},
+			
+			}
+	);
 
-        return $self;    
+	$self->{id} = $self->{session}->ID;
+
+	return $self;    
 }
 
 =head1 Default handlers and arguments
@@ -266,9 +266,9 @@ sub origin {
         return if (!$target);
 
         POE::Kernel->post(
-                $self->{session}->ID,
-                'origin',
-                $target
+			$self->{session}->ID,
+			'origin',
+			$target
         );
 }
 
@@ -482,7 +482,11 @@ Handle a socket when it is disconnected
 
 =cut
 
-sub _socket_death { }
+sub _socket_death { 
+	my ($kernel,$heap) = @_[KERNEL,HEAP];
+	
+	$kernel->post( $heap->{parent}, $heap->{handlers}->{disconnected} )	
+}
 
 =head2 _socket_input
 
